package com.ruoyi.ss.vipLevel.mapper;

import com.ruoyi.ss.vipLevel.domain.VipLevel;
import com.ruoyi.ss.vipLevel.domain.VipLevelQuery;
import com.ruoyi.ss.vipLevel.domain.VipLevelVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * VIP等级定价Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-16
 */
public interface VipLevelMapper
{
    /**
     * 查询VIP等级定价
     *
     * @param id VIP等级定价主键
     * @return VIP等级定价
     */
    VipLevelVO selectVipLevelSkuById(Long id);

    /**
     * 查询VIP等级定价列表
     *
     * @param query VIP等级定价
     * @return VIP等级定价集合
     */
    List<VipLevelVO> selectVipLevelSkuList(@Param("query") VipLevelQuery query);

    /**
     * 新增VIP等级定价
     *
     * @param vipLevel VIP等级定价
     * @return 结果
     */
    int insertVipLevelSku(VipLevel vipLevel);

    /**
     * 修改VIP等级定价
     *
     * @param vipLevel VIP等级定价
     * @return 结果
     */
    public int updateVipLevelSku(@Param("data") VipLevel vipLevel);

    /**
     * 批量删除VIP等级定价
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int logicDel(@Param("ids") List<Long> ids);

}
